@@ -21,6 +21,8 @@
 #ifndef DOCUMENT_GLOM_H
 #define DOCUMENT_GLOM_H
 
+#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
+
 #include <bakery/Document/Document_XML.h>
 #include <bakery/View/View_Composite.h>
 #include <glom/libglom/data_structure/relationship.h>
@@ -38,6 +40,7 @@
 #include <gtkmm/window.h>
 #include <vector>
 #include <map>
+#include <limits> // for numeric_limits
 
 namespace Glom
 {
@@ -72,14 +75,19 @@ public:
   Document_Glom();
   virtual ~Document_Glom();
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   virtual void set_modified(bool value = true);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
+
   virtual void set_file_uri(const Glib::ustring& file_uri, bool bEnforceFileExtension = false);
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   /** The document usually saves itself when you call set_modified().
    * Pass false to this function to prevent that temporarily.
    * The document will be saved, if necessary, after you call this function with true.
    */
   void set_allow_autosave(bool value = true);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   bool get_is_example_file() const;
   void set_is_example_file(bool value = true);
@@ -95,15 +103,18 @@ public:
 
   static guint get_latest_known_document_format_version();
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   /** When this is set, the postgres database is hosted by the local client,
    *  instead of connecting to an external database server.
    */
   void set_connection_is_self_hosted(bool self_hosted = true);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   void set_connection_server(const Glib::ustring& strVal);
   void set_connection_user(const Glib::ustring& strVal);
   void set_connection_database(const Glib::ustring& strVal);
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   /** When this returns true, the postgres database should be hosted by the local client,
    *  instead of connecting to an external database server.
    */
@@ -114,6 +125,7 @@ public:
     * This is usually a specifically-named directory at the same level as the .glom file. 
     */   
   std::string get_connection_self_hosted_directory_uri() const;
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   Glib::ustring get_connection_server() const;
   Glib::ustring get_connection_user() const;
@@ -313,7 +325,12 @@ public:
   static sharedptr<Relationship>  create_relationship_system_preferences(const Glib::ustring& table_name);
   static bool get_relationship_is_system_properties(const sharedptr<const Relationship>& relationship);
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   static void set_node_attribute_value_as_decimal(xmlpp::Element* node, const Glib::ustring& strAttributeName, int value);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
+
+  // This is required by the report builder, so it cannot be disabled
+  // in client only mode
   static void set_node_attribute_value_as_decimal_double(xmlpp::Element* node, const Glib::ustring& strAttributeName, double value);
 
 
@@ -322,13 +339,21 @@ protected:
 
   //Overrides:
   virtual bool load_after();
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   virtual bool save_before();
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   void load_after_layout_group(const xmlpp::Element* node, const Glib::ustring& table_name, const sharedptr<LayoutGroup>& group);
+
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   void save_before_layout_group(xmlpp::Element* node, const sharedptr<const LayoutGroup>& group);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   void load_after_sort_by(const xmlpp::Element* node, const Glib::ustring& table_name, LayoutItem_GroupBy::type_list_sort_fields& list_fields);
+
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   void save_before_sort_by(xmlpp::Element* node, const LayoutItem_GroupBy::type_list_sort_fields& list_fields);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   void load_after_layout_item_usesrelationship(const xmlpp::Element* element, const Glib::ustring& table_name, const sharedptr<UsesRelationship>& item);
   void load_after_layout_item_field(const xmlpp::Element* element, const Glib::ustring& table_name, const sharedptr<LayoutItem_Field>& item);
@@ -336,6 +361,7 @@ protected:
 
   void load_after_translations(const xmlpp::Element* element, TranslatableItem& item);
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   void save_before_layout_item_usesrelationship(xmlpp::Element* nodeItem, const sharedptr<const UsesRelationship>& item);
   void save_before_layout_item_field(xmlpp::Element* nodeItem, const sharedptr<const LayoutItem_Field>& item);
   void save_before_layout_item_field_formatting(xmlpp::Element* nodeItem, const FieldFormatting& format, Field::glom_field_type field_type);
@@ -343,20 +369,25 @@ protected:
   void save_before_translations(xmlpp::Element* nodeItem, const TranslatableItem& item);
 
   void save_changes();
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   void on_app_state_userlevel_changed(AppState::userlevels userlevel);
 
   void fill_translatable_layout_items(const sharedptr<LayoutGroup>& group, type_list_translatables& the_list);
 
   static bool get_node_attribute_value_as_bool(const xmlpp::Element* node, const Glib::ustring& strAttributeName);
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   static void set_node_attribute_value_as_bool(xmlpp::Element* node, const Glib::ustring& strAttributeName, bool value = true);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   static guint get_node_attribute_value_as_decimal(const xmlpp::Element* node, const Glib::ustring& strAttributeName);
   static double get_node_attribute_value_as_decimal_double(const xmlpp::Element* node, const Glib::ustring& strAttributeName);
 
   static float get_node_attribute_value_as_float(const xmlpp::Element* node, const Glib::ustring& strAttributeName);
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   static void set_node_attribute_value_as_float( xmlpp::Element* node, const Glib::ustring& strAttributeName, float value );
   static void set_node_attribute_value_as_value(xmlpp::Element* node, const Glib::ustring& strAttributeName, const Gnome::Gda::Value& value, Field::glom_field_type field_type);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
   static Gnome::Gda::Value get_node_attribute_value_as_value(const xmlpp::Element* node, const Glib::ustring& strAttributeName, Field::glom_field_type field_type);
 
   Glib::ustring get_child_text_node(const xmlpp::Element* node, const Glib::ustring& child_node_name) const;
@@ -367,7 +398,10 @@ protected:
   AppState m_app_state;
   type_signal_userlevel_changed m_signal_userlevel_changed;
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   bool m_connection_is_self_hosted;
+#endif // !GLOM_ENABLE_CLIENT_ONLY
+
   Glib::ustring m_connection_server, m_connection_user, m_connection_database;
 
   class LayoutInfo
@@ -429,7 +463,9 @@ protected:
 
   bool m_block_cache_update; //For efficiency.
   bool m_block_modified_set;
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   bool m_allow_auto_save;
+#endif // !GLOM_ENABLE_CLIENT_ONLY
   bool m_is_example;
   guint m_document_format_version;
 
