@@ -21,6 +21,8 @@
 #ifndef BOX_DATA_LIST_H
 #define BOX_DATA_LIST_H
 
+#include "config.h" // GLOM_ENABLE_CLIENT_ONLY
+
 #include "box_data.h"
 #include "../utility_widgets/db_adddel/db_adddel_withbuttons.h"
 
@@ -69,8 +71,14 @@ public:
 
   void get_record_counts(gulong& total, gulong& found) const;
 
+  #ifndef GLOM_ENABLE_CLIENT_ONLY
+  virtual void on_dialog_layout_hide(); //override
+  #endif //GLOM_ENABLE_CLIENT_ONLY
+
 protected:
   virtual void create_layout(); //override
+  virtual Document_Glom::type_mapLayoutGroupSequence create_layout_get_layout(); //overriden in Box_Data_List_Related.
+  void create_layout_add_group(const sharedptr<LayoutGroup>& layout_group);
   virtual bool fill_from_database(); //override.
   virtual void enable_buttons();
 
@@ -84,9 +92,13 @@ protected:
   virtual void on_adddel_user_added(const Gtk::TreeModel::iterator& row, guint col_with_first_value);
   virtual void on_adddel_user_reordered_columns();
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   virtual void on_adddel_user_requested_layout();
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   virtual void on_adddel_user_changed(const Gtk::TreeModel::iterator& row, guint col);
+  virtual void on_adddel_script_button_clicked(const sharedptr<const LayoutItem_Button>& layout_item, const Gtk::TreeModel::iterator& row);
+  virtual bool on_script_button_idle(const Gnome::Gda::Value& primary_key_value);
 
   virtual void on_record_added(const Gnome::Gda::Value& primary_key_value, const Gtk::TreeModel::iterator& row); //Not a signal handler. To be overridden.
   virtual void on_record_deleted(const Gnome::Gda::Value& primary_key_value);
@@ -100,6 +112,8 @@ protected:
   bool m_has_one_or_more_records;
   bool m_read_only;
 
+  bool m_reset_column_widths; //create_layout() sets these to 0 when this is set.
+
   type_signal_user_requested_details m_signal_user_requested_details;
 };
 
