@@ -25,6 +25,9 @@
 #include "box_data_list.h"
 #include "box_data_details.h"
 
+namespace Glom
+{
+
 class Notebook_Data : public Notebook_Glom
 {
 public: 
@@ -42,7 +45,10 @@ public:
 
   virtual void select_page_for_find_results(); //Details for 1, List for > 1.
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   virtual void do_menu_developer_layout(); //override
+#endif // !GLOM_ENABLE_CLIENT_ONLY
+
   virtual void do_menu_file_print(); //override
 
   void get_record_counts(gulong& total, gulong& found);
@@ -79,4 +85,6 @@ protected:
   type_signal_record_details_requested m_signal_record_details_requested;
 };
 
+} //namespace Glom
+
 #endif
