@@ -23,10 +23,14 @@
 #include "dialog_users_list.h"
 #include "dialog_new_group.h"
 #include <glom/libglom/standard_table_prefs_fields.h>
+#include <glom/glom_privs.h>
 //#include <libgnome/gnome-i18n.h>
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
+
 Dialog_GroupsList::Dialog_GroupsList(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
 : Gtk::Dialog(cobject),
   m_treeview_groups(0),
@@ -221,7 +225,7 @@ void Dialog_GroupsList::on_button_group_delete()
         if(response == Gtk::RESPONSE_OK)
         {
           Glib::ustring strQuery = "DROP GROUP " + user;
-          Query_execute(strQuery, this);
+          query_execute(strQuery, this);
 
           fill_group_list();
         }
@@ -247,7 +251,7 @@ void Dialog_GroupsList::on_button_group_new()
   }
 
   dialog->set_transient_for(*this);
-  int response = dialog->run();
+  int response = Glom::Utils::dialog_run_with_help(dialog, "dialog_new_group");
 
   const Glib::ustring group_name = dialog->m_entry_name->get_text();
 
@@ -259,7 +263,7 @@ void Dialog_GroupsList::on_button_group_new()
   if(!group_name.empty())
   {
     Glib::ustring strQuery = "CREATE GROUP " + group_name;
-    Glib::RefPtr<Gnome::Gda::DataModel> data_model = Query_execute(strQuery, this);
+    Glib::RefPtr<Gnome::Gda::DataModel> data_model = query_execute(strQuery, this);
 
     //Give the new group some sensible default privileges:
     Privileges priv;
@@ -270,11 +274,11 @@ void Dialog_GroupsList::on_button_group_new()
 
     for(Document_Glom::type_listTableInfo::const_iterator iter = table_list.begin(); iter != table_list.end(); ++iter)
     {
-      set_table_privileges(group_name, (*iter)->get_name(), priv);
+      Privs::set_table_privileges(group_name, (*iter)->get_name(), priv);
     }
 
     //Let them edit the autoincrements too:
-    set_table_privileges(group_name, GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME, priv);
+    Privs::set_table_privileges(group_name, GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME, priv);
 
     fill_group_list();
   }
@@ -310,7 +314,7 @@ void Dialog_GroupsList::on_button_group_users()
 
       dialog->set_group(group_name);
 
-      dialog->run();
+      Glom::Utils::dialog_run_with_help(dialog, "window_groups");
 
       remove_view(dialog);
       delete dialog;
@@ -364,7 +368,7 @@ void Dialog_GroupsList::fill_group_list()
   //Fill the model rows:
   m_model_groups->clear();
 
-  type_vecStrings group_list = get_database_groups();
+  type_vecStrings group_list = Privs::get_database_groups();
   for(type_vecStrings::const_iterator iter = group_list.begin(); iter != group_list.end(); ++iter)
   {
     Gtk::TreeModel::iterator iterTree = m_model_groups->append();
@@ -416,7 +420,7 @@ void Dialog_GroupsList::fill_table_list(const Glib::ustring& group_name)
       row[m_model_columns_tables.m_col_name] = table_name;
       row[m_model_columns_tables.m_col_title] = (*iter)->get_title_or_name();
 
-      const Privileges privs = get_table_privileges(group_name, table_name);
+      const Privileges privs = Privs::get_table_privileges(group_name, table_name);
       row[m_model_columns_tables.m_col_view] = privs.m_view;
       row[m_model_columns_tables.m_col_edit] = privs.m_edit;
       row[m_model_columns_tables.m_col_create] = privs.m_create;
@@ -494,7 +498,7 @@ bool Dialog_GroupsList::set_table_privilege(const Glib::ustring& table_name, con
 
   strQuery += " GROUP \"" + group_name + "\"";
 
-  Query_execute(strQuery, this); //TODO: Handle errors.
+  query_execute(strQuery, this); //TODO: Handle errors.
 
   return true;
 }
@@ -579,7 +583,7 @@ void Dialog_GroupsList::on_treeview_tables_toggled_create(const Glib::ustring& p
     const Glib::ustring group_name = get_selected_group();
     const Glib::ustring table_name = row[m_model_columns_tables.m_col_name];
 
-    bool test = set_table_privilege(table_name, group_name, bActive, PRIV_CREATE);
+    const bool test = set_table_privilege(table_name, group_name, bActive, PRIV_CREATE);
 
     if(test)
       row[m_model_columns_tables.m_col_create] = bActive;
@@ -603,7 +607,7 @@ void Dialog_GroupsList::on_treeview_tables_toggled_delete(const Glib::ustring& p
     const Glib::ustring group_name = get_selected_group();
     const Glib::ustring table_name = row[m_model_columns_tables.m_col_name];
 
-    bool test = set_table_privilege(table_name, group_name, bActive, PRIV_DELETE);
+    const bool test = set_table_privilege(table_name, group_name, bActive, PRIV_DELETE);
 
     if(test)
       row[m_model_columns_tables.m_col_delete] = bActive;
@@ -622,15 +626,11 @@ void Dialog_GroupsList::on_cell_data_group_name(Gtk::CellRenderer* renderer, con
 
       Glib::ustring name = row[m_model_columns_groups.m_col_name];
 
-      renderer_text->property_text() = get_user_visible_group_name(name);
+      renderer_text->property_text() = Privs::get_user_visible_group_name(name);
     }
   }
 }
 
-
-
-
-
-
+} //namespace Glom
 
 
